/* test program for debian bug #745795 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include <hdf5.h>

#define OFFSET    0
#define STRIDE    1
#define COUNT     10


void printdata(const char *label, const unsigned char *data, int count) {
    int i;
    printf("%s:\n    ", label);
    for (i = 0; i < count; ++i)
        printf(" %i", data[i]);
    printf("\n");
}


void readfile(const char *filename, const char *datasetname) {
    hid_t file_id, dataset_id, space_id, mem_space_id, dtype_id;
    hsize_t dims[] = {0};
    hsize_t count[] = {COUNT};
    hsize_t stride[] = {STRIDE};
    hsize_t offset[] = {OFFSET};
    unsigned char data[COUNT];
    int rank = 0;

    printf("FILENAME: %s\n", filename);

    file_id = H5Fopen(filename, H5F_ACC_RDONLY, H5P_DEFAULT);
    dataset_id = H5Dopen(file_id, datasetname, H5P_DEFAULT);
    space_id = H5Dget_space(dataset_id);
    dtype_id = H5Dget_type(dataset_id);
    rank = H5Sget_simple_extent_ndims(space_id);
    H5Sget_simple_extent_dims(space_id, dims, NULL);
    H5Sselect_hyperslab(space_id, H5S_SELECT_SET, offset, stride, count, NULL);
    mem_space_id = H5Screate_simple(rank, count, NULL);

    memset(data, 3, COUNT);
    printdata("input buffer", data, COUNT);

    H5Dread(dataset_id, dtype_id, mem_space_id, space_id, H5P_DEFAULT, data);

    printdata("read data", data, COUNT);

    H5Tclose(dtype_id);
    H5Sclose(mem_space_id);
    H5Sclose(space_id);
    H5Dclose(dataset_id);
    H5Fclose(file_id);
}


int main(int argc, char* argv[]) {
    readfile("bugged_file.h5", "buggedArray");
    /*readfile("testdata.h5", "dataset");*/
    return 0;
}

